@@ -46,15 +46,6 @@ extern void gpm_marshal_VOID__INT_LONG_BOOLEAN_BOOLEAN (GClosure     *closure,
                                                         gpointer      marshal_data);
 #define gpm_marshal_NONE__INT_LONG_BOOLEAN_BOOLEAN	gpm_marshal_VOID__INT_LONG_BOOLEAN_BOOLEAN
 
-/* NONE:INT,LONG,BOOLEAN,BOOLEAN,BOOLEAN,BOOLEAN (gpm-marshal.list:6) */
-extern void gpm_marshal_VOID__INT_LONG_BOOLEAN_BOOLEAN_BOOLEAN_BOOLEAN (GClosure     *closure,
-                                                                        GValue       *return_value,
-                                                                        guint         n_param_values,
-                                                                        const GValue *param_values,
-                                                                        gpointer      invocation_hint,
-                                                                        gpointer      marshal_data);
-#define gpm_marshal_NONE__INT_LONG_BOOLEAN_BOOLEAN_BOOLEAN_BOOLEAN	gpm_marshal_VOID__INT_LONG_BOOLEAN_BOOLEAN_BOOLEAN_BOOLEAN
-
 G_END_DECLS
 
 #endif /* __gpm_marshal_MARSHAL_H__ */
