@@ -1,14 +1,14 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
  *
- * Copyright (C) 2005 Richard Hughes <hughsient@gmail.com>
  * Copyright (C) 2005 Jaap Haitsma <jaap@haitsma.org>
+ * Copyright (C) 2005-2006 Richard Hughes <richard@hughsie.com>
  *
  * Licensed under the GNU General Public License Version 2
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License
- * as published by the Free Software Foundation; either version 2
- * of the License, or (at your option) any later version.
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -17,12 +17,13 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
- * 02110-1301, USA.
+ * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
-#ifndef _GPM_PREFS_H
-#define _GPM_PREFS_H
+#ifndef __GPM_PREFS_H
+#define __GPM_PREFS_H
+
+G_BEGIN_DECLS
 
 #define GPM_PREF_DIR 			"/apps/gnome-power-manager"
 
@@ -54,5 +55,7 @@ typedef enum {
 #define ACTION_HIBERNATE		"hibernate"
 #define ACTION_NOTHING			"nothing"
 
-#endif	/* _GPM_PREFS_H */
+G_END_DECLS
+
+#endif	/* __GPM_PREFS_H */
 
