@@ -1,18 +1,15 @@
-/** @file	gpm-screensaver.c
- *  @brief	Functions to query and control GNOME Screensaver
- *  @author	Richard Hughes <richard@hughsie.com>
- *  @date	2005-10-02
+/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
+ *
+ * Copyright (C) 2005 Jaap Haitsma <jaap@haitsma.org>
+ * Copyright (C) 2005 William Jon McCann <mccann@jhu.edu>
+ * Copyright (C) 2005-2006 Richard Hughes <richard@hughsie.com>
  *
- * This module deals with communicating through DBUS and gconf to 
- * gnome-screensaver.
- */
-/*
  * Licensed under the GNU General Public License Version 2
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License
- * as published by the Free Software Foundation; either version 2
- * of the License, or (at your option) any later version.
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -21,14 +18,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
- * 02110-1301, USA.
- */
-/**
- * @addtogroup	gs		GnomeScreensaver integration
- * @brief	gs		integration into gnome-screensaver using DBUS
- *
- * @{
+ * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -40,6 +30,7 @@
 #include <gconf/gconf-client.h>
 
 #include "gpm-screensaver.h"
+#include "gpm-debug.h"
 
 #define GS_LISTENER_SERVICE	"org.gnome.ScreenSaver"
 #define GS_LISTENER_PATH	"/org/gnome/ScreenSaver"
@@ -55,7 +46,7 @@ gpm_screensaver_get_session_conn (DBusGConnection **connection)
 	session_conn = dbus_g_bus_get (DBUS_BUS_SESSION, &error);
 	if (!session_conn) {
 		if (error) {
-			g_warning ("gpm_screensaver_get_session_conn: %s", error->message);
+			gpm_warning ("%s", error->message);
 			g_error_free (error);
 		}
 		return FALSE;
@@ -107,7 +98,7 @@ gpm_screensaver_is_running (void)
 				G_TYPE_INVALID,
 				G_TYPE_BOOLEAN, &temp, G_TYPE_INVALID)) {
 		if (error) {
-			g_warning ("gpm_screensaver_is_running: %s", error->message);
+			gpm_warning ("%s", error->message);
 			g_error_free (error);
 		}
 		boolret = FALSE;
@@ -129,7 +120,7 @@ gpm_screensaver_enable_throttle (gboolean enable)
 	DBusGProxy *gs_proxy = NULL;
 	gboolean boolret = TRUE;
 
-	g_debug ("gnome-screensaver setThrottleEnabled : %i", enable);
+	gpm_debug ("setThrottleEnabled : %i", enable);
 	if (!gpm_screensaver_get_session_conn (&session_connection))
 		return FALSE;
 	gs_proxy = dbus_g_proxy_new_for_name (session_connection,
@@ -140,15 +131,15 @@ gpm_screensaver_enable_throttle (gboolean enable)
 				G_TYPE_BOOLEAN, enable, G_TYPE_INVALID,
 				G_TYPE_INVALID)) {
 		if (error) {
-			g_warning ("gpm_screensaver_enable_throttle: %s", error->message);
+			gpm_warning ("%s", error->message);
 			g_error_free (error);
 		}
-		g_debug ("gnome-screensaver service is not running.");
+		gpm_debug ("gnome-screensaver service is not running.");
 		boolret = FALSE;
 	}
 	g_object_unref (G_OBJECT (gs_proxy));
 	if (!boolret) {
-		g_debug ("gnome-screensaver setThrottleEnabled failed");
+		gpm_debug ("setThrottleEnabled failed");
 		return FALSE;
 	}
 	return TRUE;
@@ -163,7 +154,7 @@ gpm_screensaver_lock (void)
 {
 	DBusGConnection *session_connection = NULL;
 	DBusGProxy *gs_proxy = NULL;
-	g_debug ("gnome-screensaver lock");
+	gpm_debug ("lock");
 	if (!gpm_screensaver_get_session_conn (&session_connection))
 		return FALSE;
 	gs_proxy = dbus_g_proxy_new_for_name (session_connection,
@@ -185,7 +176,7 @@ gpm_screensaver_poke (void)
 {
 	DBusGConnection *session_connection = NULL;
 	DBusGProxy *gs_proxy = NULL;
-	g_debug ("gnome-screensaver poke");
+	gpm_debug ("poke");
 	if (!gpm_screensaver_get_session_conn (&session_connection))
 		return FALSE;
 	gs_proxy = dbus_g_proxy_new_for_name (session_connection,
@@ -220,17 +211,16 @@ gpm_screensaver_get_idle (gint *time)
 				G_TYPE_INVALID,
 				G_TYPE_UINT, time, G_TYPE_INVALID)) {
 		if (error) {
-			g_warning ("gpm_screensaver_get_idle: %s", error->message);
+			gpm_warning ("%s", error->message);
 			g_error_free (error);
 		}
-		g_debug ("gnome-screensaver service is not running.");
+		gpm_debug ("gnome-screensaver service is not running.");
 		boolret = FALSE;
 	}
 	g_object_unref (G_OBJECT (gs_proxy));
 	if (!boolret) {
-		g_debug ("gnome-screensaver get idle failed");
+		gpm_debug ("get idle failed");
 		return FALSE;
 	}
 	return TRUE;
 }
-/** @} */
