@@ -1,6 +1,9 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
  *
  * Copyright (C) 2005 William Jon McCann <mccann@jhu.edu>
+ * Copyright (C) 2005-2006 Richard Hughes <richard@hughsie.com>
+ *
+ * Licensed under the GNU General Public License Version 2
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -15,9 +18,6 @@
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
- *
- * Authors: William Jon McCann <mccann@jhu.edu>
- *
  */
 
 #ifdef HAVE_CONFIG_H
@@ -45,9 +45,10 @@
 #include <libnotify/notify.h>
 #endif
 
-#include "gpm-common.h" /* For GPMURL, etc */
+#include "gpm-common.h" /* For GPM_HOMEPAGE_URL, etc */
 #include "gpm-stock-icons.h"
 #include "gpm-tray-icon.h"
+#include "gpm-debug.h"
 
 static void     gpm_tray_icon_class_init (GpmTrayIconClass *klass);
 static void     gpm_tray_icon_init       (GpmTrayIcon      *tray_icon);
@@ -65,12 +66,11 @@ struct GpmTrayIconPrivate
 	GtkWidget      *ebox;
 
 	gboolean        show_notifications;
+	gboolean        is_visible;
 
 	gboolean        can_suspend;
 	gboolean        can_hibernate;
 
-	gboolean        embedded;
-
 #if (LIBNOTIFY_VERSION_MINOR == 2)
 	NotifyHandle   *notify;
 #elif (LIBNOTIFY_VERSION_MINOR >= 3)
@@ -79,14 +79,14 @@ struct GpmTrayIconPrivate
 };
 
 enum {
-        SUSPEND,
-        HIBERNATE,
-        LAST_SIGNAL
+	SUSPEND,
+	HIBERNATE,
+	LAST_SIGNAL
 };
 
 enum {
-        PROP_0,
-        PROP_MODE
+	PROP_0,
+	PROP_MODE
 };
 
 typedef enum {
@@ -173,9 +173,9 @@ gpm_tray_icon_set_tooltip (GpmTrayIcon *icon,
 void
 gpm_tray_icon_set_image_from_stock (GpmTrayIcon *icon,
 				    const char  *stock_id)
-			
 {
 	g_return_if_fail (GPM_IS_TRAY_ICON (icon));
+	gpm_debug ("Setting icon to %s", stock_id);
 
 	if (stock_id) {
 		gtk_image_set_from_stock (GTK_IMAGE (icon->priv->image),
@@ -196,6 +196,7 @@ static void
 gpm_tray_icon_hibernate_cb (GtkAction   *action,
 			    GpmTrayIcon *icon)
 {
+	gpm_debug ("emitting hibernate");
 	g_signal_emit (icon, signals [HIBERNATE], 0);
 }
 
@@ -203,6 +204,7 @@ static void
 gpm_tray_icon_suspend_cb (GtkAction   *action,
 			  GpmTrayIcon *icon)
 {
+	gpm_debug ("emitting suspend");
 	g_signal_emit (icon, signals [SUSPEND], 0);
 }
 
@@ -212,9 +214,9 @@ gpm_tray_icon_show_preferences_cb (GtkAction   *action,
 {
 	const char *command = "gnome-power-preferences";
 
-        if (! g_spawn_command_line_async (command, NULL)) {
-                g_warning ("Couldn't execute command: %s", command);
-        }
+	if (! g_spawn_command_line_async (command, NULL)) {
+		gpm_warning ("Couldn't execute command: %s", command);
+	}
 }
 
 static void
@@ -225,7 +227,7 @@ gpm_tray_icon_show_help_cb (GtkAction   *action,
 
 	gnome_help_display ("gnome-power-manager.xml", NULL, &error);
 	if (error != NULL) {
-		g_warning (error->message);
+		gpm_warning (error->message);
 		g_error_free (error);
 	}
 }
@@ -246,18 +248,18 @@ gpm_tray_icon_show_about_cb (GtkAction  *action,
 		"Diana Fong <dfong@redhat.com>",
 		NULL};
 	const char *license[] = {
-		N_("Licensed under the GNU General Public License Version 2"), 
-		N_("Power Manager is free software; you can redistribute it and/or\n" 
-		   "modify it under the terms of the GNU General Public License\n" 
-		   "as published by the Free Software Foundation; either version 2\n" 
-		   "of the License, or (at your option) any later version."), 
-		N_("Power Manager is distributed in the hope that it will be useful,\n" 
-		   "but WITHOUT ANY WARRANTY; without even the implied warranty of\n" 
-		   "MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the\n" 
-		   "GNU General Public License for more details."), 
-		N_("You should have received a copy of the GNU General Public License\n" 
-		   "along with this program; if not, write to the Free Software\n" 
-		   "Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA\n" 
+		N_("Licensed under the GNU General Public License Version 2"),
+		N_("Power Manager is free software; you can redistribute it and/or\n"
+		   "modify it under the terms of the GNU General Public License\n"
+		   "as published by the Free Software Foundation; either version 2\n"
+		   "of the License, or (at your option) any later version."),
+		N_("Power Manager is distributed in the hope that it will be useful,\n"
+		   "but WITHOUT ANY WARRANTY; without even the implied warranty of\n"
+		   "MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the\n"
+		   "GNU General Public License for more details."),
+		N_("You should have received a copy of the GNU General Public License\n"
+		   "along with this program; if not, write to the Free Software\n"
+		   "Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA\n"
 		   "02110-1301, USA.")
 	};
   	const char  *translators = _("translator-credits");
@@ -267,8 +269,9 @@ gpm_tray_icon_show_about_cb (GtkAction  *action,
 	/*
 	 * Translators comment: put your own name here to appear in the about dialog.
 	 */
-  	if (!strcmp (translators, "translator-credits"))
+  	if (!strcmp (translators, "translator-credits")) {
 		translators = NULL;
+	}
 
 	pixbuf = gdk_pixbuf_new_from_file (GPM_DATA "gnome-power.png", NULL);
 
@@ -276,18 +279,18 @@ gpm_tray_icon_show_about_cb (GtkAction  *action,
 				     _(license[2]), "\n\n", _(license[3]), "\n",  NULL);
 
 	gtk_show_about_dialog (NULL,
-                               "name", NICENAME,
-                               "version", VERSION,
-                               "copyright", "Copyright \xc2\xa9 2005 Richard Hughes",
-                               "license", license_trans,
-                               "website", GPMURL,
-                               "comments", NICEDESC,
-                               "authors", authors,
-                               "documenters", documenters,
-                               "artists", artists,
-                               "translator-credits", translators,
-                               "logo", pixbuf,
-                               NULL);
+		               "name", GPM_NAME,
+		               "version", VERSION,
+		               "copyright", "Copyright \xc2\xa9 2005 Richard Hughes",
+		               "license", license_trans,
+		               "website", GPM_HOMEPAGE_URL,
+		               "comments", GPM_DESCRIPTION,
+		               "authors", authors,
+		               "documenters", documenters,
+		               "artists", artists,
+		               "translator-credits", translators,
+		               "logo", pixbuf,
+		               NULL);
 
 	g_object_unref (pixbuf);
 }
@@ -313,10 +316,11 @@ tray_popup_position_menu (GtkMenu  *menu,
 	menu_xpos += widget->allocation.x;
 	menu_ypos += widget->allocation.y;
 
-	if (menu_ypos > gdk_screen_get_height (gtk_widget_get_screen (widget)) / 2)
+	if (menu_ypos > gdk_screen_get_height (gtk_widget_get_screen (widget)) / 2) {
 		menu_ypos -= (requisition.height + 1);
-	else
+	} else {
 		menu_ypos += widget->allocation.height + 1;
+	}
 
 	*x = menu_xpos;
 	*y = menu_ypos;
@@ -396,7 +400,7 @@ gpm_tray_icon_constructor (GType                  type,
 
 	klass = GPM_TRAY_ICON_CLASS (g_type_class_peek (GPM_TYPE_TRAY_ICON));
 
-	tray = GPM_TRAY_ICON (G_OBJECT_CLASS (gpm_tray_icon_parent_class)->constructor 
+	tray = GPM_TRAY_ICON (G_OBJECT_CLASS (gpm_tray_icon_parent_class)->constructor
 			      (type, n_construct_properties,
 			       construct_properties));
 
@@ -426,7 +430,7 @@ gpm_tray_icon_constructor (GType                  type,
 					   "</ui>",
 					   -1, &error);
 	if (error != NULL) {
-		g_warning ("Couldn't merge user interface for popup: %s", error->message);
+		gpm_warning ("Couldn't merge user interface for popup: %s", error->message);
 		g_clear_error (&error);
 	}
 
@@ -437,59 +441,56 @@ gpm_tray_icon_constructor (GType                  type,
 	return G_OBJECT (tray);
 }
 
-static void
-gpm_tray_icon_embedded (GtkPlug *plug)
-{
-	GpmTrayIcon *tray;
-
-	tray = GPM_TRAY_ICON (plug);
-
-	tray->priv->embedded = TRUE;
-
-	if (GTK_PLUG_CLASS (parent_class)->embedded)
-		GTK_PLUG_CLASS (parent_class)->embedded (plug);
-}
-
 static void
 gpm_tray_icon_class_init (GpmTrayIconClass *klass)
 {
 	GObjectClass   *object_class = G_OBJECT_CLASS (klass);
-	GtkPlugClass   *plug_class = GTK_PLUG_CLASS (klass);
 
 	parent_class = g_type_class_peek_parent (klass);
 
 	object_class->finalize	   = gpm_tray_icon_finalize;
 	object_class->get_property = gpm_tray_icon_get_property;
 	object_class->set_property = gpm_tray_icon_set_property;
-        object_class->constructor  = gpm_tray_icon_constructor;
-
-	plug_class->embedded       = gpm_tray_icon_embedded;
+	object_class->constructor  = gpm_tray_icon_constructor;
 
 	g_type_class_add_private (klass, sizeof (GpmTrayIconPrivate));
 
-        signals [SUSPEND] =
-                g_signal_new ("suspend",
-                              G_TYPE_FROM_CLASS (object_class),
-                              G_SIGNAL_RUN_LAST,
-                              G_STRUCT_OFFSET (GpmTrayIconClass, suspend),
-                              NULL,
-                              NULL,
-                              g_cclosure_marshal_VOID__VOID,
-                              G_TYPE_NONE,
-                              0);
-        signals [HIBERNATE] =
-                g_signal_new ("hibernate",
-                              G_TYPE_FROM_CLASS (object_class),
-                              G_SIGNAL_RUN_LAST,
-                              G_STRUCT_OFFSET (GpmTrayIconClass, hibernate),
-                              NULL,
-                              NULL,
-                              g_cclosure_marshal_VOID__VOID,
-                              G_TYPE_NONE,
-                              0);
+	signals [SUSPEND] =
+		g_signal_new ("suspend",
+		              G_TYPE_FROM_CLASS (object_class),
+		              G_SIGNAL_RUN_LAST,
+		              G_STRUCT_OFFSET (GpmTrayIconClass, suspend),
+		              NULL,
+		              NULL,
+		              g_cclosure_marshal_VOID__VOID,
+		              G_TYPE_NONE,
+		              0);
+	signals [HIBERNATE] =
+		g_signal_new ("hibernate",
+		              G_TYPE_FROM_CLASS (object_class),
+		              G_SIGNAL_RUN_LAST,
+		              G_STRUCT_OFFSET (GpmTrayIconClass, hibernate),
+		              NULL,
+		              NULL,
+		              g_cclosure_marshal_VOID__VOID,
+		              G_TYPE_NONE,
+		              0);
 
 }
 
+void
+gpm_tray_icon_show (GpmTrayIcon *icon,
+		    gboolean     enabled)
+{
+	if (enabled) {
+		gtk_widget_show_all (GTK_WIDGET (icon));
+		icon->priv->is_visible = TRUE;
+	} else {
+		gtk_widget_hide_all (GTK_WIDGET (icon));
+		icon->priv->is_visible = FALSE;
+	}
+}
+
 static void
 gpm_tray_icon_init (GpmTrayIcon *icon)
 {
@@ -500,29 +501,30 @@ gpm_tray_icon_init (GpmTrayIcon *icon)
 	/* FIXME: make this a property */
 	icon->priv->show_notifications = TRUE;
 
-        icon->priv->tooltips = gtk_tooltips_new ();
+	icon->priv->tooltips = gtk_tooltips_new ();
 	icon->priv->ui_manager = gtk_ui_manager_new ();
 
-        icon->priv->ebox = gtk_event_box_new ();
-        g_signal_connect_object (G_OBJECT (icon->priv->ebox),
-                                 "button_press_event",
-                                 G_CALLBACK (gpm_tray_icon_button_press_cb),
-                                 icon, 0);
+	icon->priv->ebox = gtk_event_box_new ();
+	g_signal_connect_object (G_OBJECT (icon->priv->ebox),
+		                 "button_press_event",
+		                 G_CALLBACK (gpm_tray_icon_button_press_cb),
+		                 icon, 0);
 
 	icon->priv->image = gtk_image_new ();
 
-        gtk_container_add (GTK_CONTAINER (icon->priv->ebox), icon->priv->image);
+	gtk_container_add (GTK_CONTAINER (icon->priv->ebox), icon->priv->image);
 
-        gtk_container_add (GTK_CONTAINER (icon), icon->priv->ebox);
-        gtk_widget_show_all (GTK_WIDGET (icon->priv->ebox));
+	gtk_container_add (GTK_CONTAINER (icon), icon->priv->ebox);
+	gpm_tray_icon_show (GPM_TRAY_ICON (icon), FALSE);
 
 #if (LIBNOTIFY_VERSION_MINOR >= 3)
-	ret = notify_init (NICENAME);
+	ret = notify_init (GPM_NAME);
 #elif (LIBNOTIFY_VERSION_MINOR == 2)
-	ret = notify_glib_init (NICENAME, NULL);
+	ret = notify_glib_init (GPM_NAME, NULL);
 #endif
-	if (!ret)
-		g_warning ("gpm_tray_icon_init failed");
+	if (!ret) {
+		gpm_warning ("gpm_tray_icon_init failed");
+	}
 }
 
 static void
@@ -537,7 +539,7 @@ gpm_tray_icon_finalize (GObject *object)
 
 	g_return_if_fail (tray_icon->priv != NULL);
 
-        gtk_object_destroy (GTK_OBJECT (tray_icon->priv->tooltips));
+	gtk_object_destroy (GTK_OBJECT (tray_icon->priv->tooltips));
 
 	G_OBJECT_CLASS (parent_class)->finalize (object);
 }
@@ -558,10 +560,7 @@ get_widget_position (GtkWidget *widget,
 		     int       *x,
 		     int       *y)
 {
-	/* assertion checks */
 	g_assert (widget);
-	g_assert (x);
-	g_assert (y);
 
 	gdk_window_get_origin (GDK_WINDOW (widget->window), x, y);
 
@@ -570,7 +569,7 @@ get_widget_position (GtkWidget *widget,
 	*x += widget->allocation.width / 2;
 	*y += widget->allocation.height;
 
-	g_debug ("widget position x=%i, y=%i", *x, *y);
+	gpm_debug ("widget position x=%i, y=%i", *x, *y);
 
 	return TRUE;
 }
@@ -583,7 +582,7 @@ notification_closed_cb (NotifyNotification *notify,
 			GpmTrayIcon        *tray)
 {
 	/* just invalidate the pointer */
-	g_debug ("caught notification closed signal");
+	gpm_debug ("caught notification closed signal");
 	tray->priv->notify = NULL;
 }
 
@@ -603,21 +602,24 @@ libnotify_event (GpmTrayIcon             *tray,
 
 	tray->priv->notify = notify_notification_new (subject, content, GNOME_DEV_BATTERY, NULL);
 
-        notify_notification_set_timeout (tray->priv->notify, timeout);
+	notify_notification_set_timeout (tray->priv->notify, timeout);
 
-	get_widget_position (GTK_WIDGET (tray), &x, &y);
-	notify_notification_set_hint_int32 (tray->priv->notify, "x", x);
-	notify_notification_set_hint_int32 (tray->priv->notify, "y", y);
+	if (tray->priv->is_visible) {
+		get_widget_position (GTK_WIDGET (tray), &x, &y);
+		notify_notification_set_hint_int32 (tray->priv->notify, "x", x);
+		notify_notification_set_hint_int32 (tray->priv->notify, "y", y);
+	}
 
-	if (urgency == LIBNOTIFY_URGENCY_CRITICAL)
-		g_warning ("libnotify: %s : %s", NICENAME, content);
-	else
-		g_debug ("libnotify: %s : %s", NICENAME, content);
+	if (urgency == LIBNOTIFY_URGENCY_CRITICAL) {
+		gpm_warning ("libnotify: %s : %s", GPM_NAME, content);
+	} else {
+		gpm_debug ("libnotify: %s : %s", GPM_NAME, content);
+	}
 
 	g_signal_connect (tray->priv->notify, "closed", G_CALLBACK (notification_closed_cb), tray);
 
 	if (! notify_notification_show (tray->priv->notify, NULL)) {
-		g_warning ("failed to send notification (%s)", content);
+		gpm_warning ("failed to send notification (%s)", content);
 		return FALSE;
 	}
 
@@ -641,16 +643,18 @@ libnotify_event (GpmTrayIcon             *tray,
 	/* assertion checks */
 	g_assert (content);
 
-	get_widget_position (GTK_WIDGET (tray), &x, &y);
-	hints = notify_hints_new();
-	notify_hints_set_int (hints, "x", x);
-	notify_hints_set_int (hints, "y", y);
-
+	hints = notify_hints_new ();
+	if (tray->priv->is_visible) {
+		get_widget_position (GTK_WIDGET (tray), &x, &y);
+		notify_hints_set_int (hints, "x", x);
+		notify_hints_set_int (hints, "y", y);
+	}
 	/* echo to terminal too */
-	if (urgency == LIBNOTIFY_URGENCY_CRITICAL)
-		g_warning ("libnotify: %s : %s", NICENAME, content);
-	else
-		g_debug ("libnotify: %s : %s", NICENAME, content);
+	if (urgency == LIBNOTIFY_URGENCY_CRITICAL) {
+		gpm_warning ("libnotify: %s : %s", GPM_NAME, content);
+	} else {
+		gpm_debug ("libnotify: %s : %s", GPM_NAME, content);
+	}
 
 	/* use default g-p-m icon for now */
 	icon = notify_icon_new_from_uri (GPM_DATA "gnome-power.png");
@@ -673,7 +677,7 @@ libnotify_event (GpmTrayIcon             *tray,
 	notify_icon_destroy (icon);
 
 	if (! tray->priv->notify) {
-		g_warning ("failed to send notification (%s)", content);
+		gpm_warning ("failed to send notification (%s)", content);
 		return FALSE;
 	}
 
@@ -696,17 +700,18 @@ libnotify_event (GpmTrayIcon             *tray,
 	/* assertion checks */
 	g_assert (content);
 
-	if (urgency == LIBNOTIFY_URGENCY_CRITICAL)
+	if (urgency == LIBNOTIFY_URGENCY_CRITICAL) {
 		msg_type = GTK_MESSAGE_WARNING;
-	else
+	} else {
 		msg_type = GTK_MESSAGE_INFO;
+	}
 
 	dialog = gtk_message_dialog_new_with_markup (NULL,
 						     GTK_DIALOG_DESTROY_WITH_PARENT,
 						     msg_type,
 						     GTK_BUTTONS_CLOSE,
 						     "<span size='larger'><b>%s</b></span>",
-						     NICENAME);
+						     GPM_NAME);
 
 	gtk_message_dialog_format_secondary_markup (GTK_MESSAGE_DIALOG (dialog), content);
 
@@ -730,17 +735,12 @@ gpm_tray_icon_notify (GpmTrayIcon *icon,
 {
 	g_return_if_fail (GPM_IS_TRAY_ICON (icon));
 
-	if (!icon->priv->show_notifications) {
-		g_debug ("ignoring notification: %s", primary);
+	if (! icon->priv->show_notifications) {
+		gpm_debug ("ignoring notification: %s", primary);
 		return;
 	}
 
-	if (! icon->priv->embedded) {
-		g_debug ("Not embedded in a tray - ignoring notification");
-		return;
-	}
-
-	g_debug ("doing notify: %s", primary);
+	gpm_debug ("doing notify: %s", primary);
 
 	libnotify_event (icon,
 			 timeout,
@@ -761,7 +761,7 @@ gpm_tray_icon_cancel_notify (GpmTrayIcon *icon)
 #if LIBNOTIFY_VERSION_MINOR >= 2
 	if (icon->priv->notify != NULL) {
 #if (LIBNOTIFY_VERSION_MINOR >= 3)
-		notify_notification_close (icon->priv->notify, &error);	
+		notify_notification_close (icon->priv->notify, &error);
 #elif (LIBNOTIFY_VERSION_MINOR == 2)
 		notify_close (icon->priv->notify);
 		icon->priv->notify = NULL;
